@@ -1,7 +1,7 @@
 package SQL::Dialects::AnyData;
 
 use vars qw($VERSION);
-$VERSION = '0.1';
+$VERSION = '1.21';
 
 sub get_config {
 return <<EOC;
@@ -32,6 +32,10 @@ RLIKE
 NOT RLIKE
 IS
 IS NOT
+IN
+NOT IN
+BETWEEN
+NOT BETWEEN
 
 [VALID DATA TYPES]
 CHAR
