@@ -1,23 +1,9 @@
 package SQL::Statement::Function;
 
-######################################################################
-#
-# This module is copyright (c), 2009-2020 by Jens Rehsack.
-# All rights reserved.
-#
-# It may be freely distributed under the same terms as Perl itself.
-# See below for help and copyright information (search for SYNOPSIS).
-#
-######################################################################
-
-use strict;
-use warnings FATAL => "all";
-use vars qw(@ISA $VERSION);
-
-use SQL::Statement::Term ();
+require SQL::Statement::Term;
 @ISA = qw(SQL::Statement::Term);
 
-$VERSION = '1.413_001';
+our $VERSION = '1.21';
 
 =pod
 
@@ -27,7 +13,7 @@ SQL::Statement::Function - abstract base class for all function executing terms
 
 =head1 SYNOPSIS
 
-  # this class does not have a common constructor, because all derived classes
+  # this class doesn't have a common constructor, because all derived classes
   # have their special requirements
 
 =head1 DESCRIPTION
@@ -62,7 +48,7 @@ package SQL::Statement::Function::UserFunc;
 
 use vars qw(@ISA);
 
-use Carp ();
+require Carp;
 use Params::Util qw(_INSTANCE);
 
 use SQL::Statement::Functions;
@@ -102,7 +88,7 @@ Instantiates a new C<SQL::Statement::Function::UserFunc> instance.
 
 =head2 value
 
-Invokes the given subroutine with the values of the params and return it's
+Invokes the given soubroutine with the values of the params and return it's
 result:
 
     my @params = map { $_->value($eval); } @{ $self->{PARAMS} };
@@ -138,10 +124,10 @@ sub new
             $mod =~ s|::|/|g;
             $mod .= '.pm';
             eval { require $mod; } unless ( defined( $INC{$mod} ) );
-            return $owner->do_err($@) if ($@);
+            return $owner->do_er($@) if ($@);
         }
 
-        $pkg->can($sub) or return $owner->do_err( "Can't find subroutine $pkg" . "::$sub" );
+        $pkg->can($sub) or return $owner->do_er( "Can't find subroutine $pkg" . "::$sub" );
     }
 
     return $self;
@@ -161,7 +147,7 @@ package SQL::Statement::Function::NumericEval;
 
 use vars qw(@ISA);
 
-use Params::Util qw(_NUMBER _INSTANCE);
+use Params::Util qw(_NUMBER);
 
 @ISA = qw(SQL::Statement::Function);
 
@@ -205,7 +191,7 @@ Returns the result of the evaluated expression.
 
 sub new
 {
-    my ( $class, $owner, $expr, $params ) = @_;
+    my ($class,$owner,$expr,$params) = @_;
 
     my $self = $class->SUPER::new($owner);
 
@@ -218,14 +204,13 @@ sub new
 sub value($)
 {
     my ( $self, $eval ) = @_;
-    my @vals =
-      map { _INSTANCE( $_, 'SQL::Statement::Term' ) ? $_->value($eval) : $_ } @{ $self->{PARAMS} };
+    my $expr = $self->{EXPR};
+    my @vals = map { _INSTANCE( $_, 'SQL::Statement::Term' ) ? $_->value($eval) : $_ } @{ $self->{PARAMS} };
     foreach my $val (@vals)
     {
-        return $self->{OWNER}->do_err(qq~Bad numeric expression '$val'!~)
+        return $self->do_err(qq~Bad numeric expression '$val'!~)
           unless ( defined( _NUMBER($val) ) );
     }
-    my $expr = $self->{EXPR};
     $expr =~ s/\?(\d+)\?/$vals[$1]/g;
     $expr =~ s/\s//g;
     $expr =~ s/^([\)\(+\-\*\/\%0-9]+)$/$1/;    # untaint
@@ -287,7 +272,7 @@ The character to trim - defaults to C<' '>
 
 =item I<\@params>
 
-Expected to be an array with exact 1 element (more are not evaluated).
+Expected to be an array with exact 1 element (more aren't evaluated).
 
 =back
 
@@ -299,9 +284,9 @@ Returns the trimmed value of first parameter argument.
 
 sub new
 {
-    my ( $class, $owner, $spec, $char, $params ) = @_;
-    $spec ||= 'BOTH';
-    $char ||= ' ';
+    my ($class, $owner, $spec, $char, $params ) = @_;
+    $spec   ||= 'BOTH';
+    $char   ||= ' ';
 
     my $self = $class->SUPER::new($owner);
 
@@ -381,7 +366,7 @@ If omitted, everything to the end of the string is returned.
 
 =item I<\@params>
 
-Expected to be an array with exact 1 element (more are not evaluated).
+Expected to be an array with exact 1 element (more aren't evaluated).
 
 =back
 
@@ -393,7 +378,7 @@ Returns the extracted sub-string value from first parameter argument.
 
 sub new
 {
-    my ( $class, $owner, $start, $length, $params ) = @_;
+    my ($class,$owner,$start,$length,$params) = @_;
 
     my $self = $class->SUPER::new($owner);
 
@@ -406,10 +391,9 @@ sub new
 
 sub value($)
 {
-    my $val   = $_[0]->{PARAMS}->[0]->value( $_[1] );
-    my $start = $_[0]->{START}->value( $_[1] ) - 1;
-    my $length =
-      defined( $_[0]->{LENGTH} ) ? $_[0]->{LENGTH}->value( $_[1] ) : length($val) - $start;
+    my $val    = $_[0]->{PARAMS}->[0]->value( $_[1] );
+    my $start  = $_[0]->{START}->value( $_[1] ) - 1;
+    my $length = defined( $_[0]->{LENGTH} ) ? $_[0]->{LENGTH}->value( $_[1] ) : length($val) - $start;
     return substr( $val, $start, $length );
 }
 
@@ -457,7 +441,7 @@ Returns the concatenated string composed of the parameter values.
 
 sub new
 {
-    my ( $class, $owner, $params ) = @_;
+    my ($class,$owner,$params ) = @_;
 
     my $self = $class->SUPER::new($owner);
 
@@ -471,15 +455,14 @@ sub value($)
     my $rc = '';
     foreach my $val ( @{ $_[0]->{PARAMS} } )
     {
-        my $catval = $val->value( $_[1] );
-        $rc .= defined($catval) ? $catval : '';
+        $rc .= $val->value( $_[1] );
     }
     return $rc;
 }
 
 =head1 AUTHOR AND COPYRIGHT
 
-Copyright (c) 2009-2020 by Jens Rehsack: rehsackATcpan.org
+Copyright (c) 2009 by Jens Rehsack: rehsackATcpan.org
 
 All rights reserved.
 
