@@ -1,24 +1,11 @@
 package SQL::Statement::Operation;
 
-######################################################################
-#
-# This module is copyright (c), 2009-2020 by Jens Rehsack.
-# All rights reserved.
-#
-# It may be freely distributed under the same terms as Perl itself.
-# See below for help and copyright information (search for SYNOPSIS).
-#
-######################################################################
-
-use strict;
-use warnings FATAL => "all";
-
 use vars qw(@ISA);
-use Carp ();
+require Carp;
 
-use SQL::Statement::Term ();
+require SQL::Statement::Term;
 
-our $VERSION = '1.413_001';
+our $VERSION = '1.21';
 
 @ISA = qw(SQL::Statement::Term);
 
@@ -62,18 +49,6 @@ Return the result of the operation of the term by calling L<operate>
 I<Abstract> method which will do the operation of the term. Must be
 overridden by derived classes.
 
-=head2 op
-
-Returns the name of the executed operation.
-
-=head2 left
-
-Returns the left operand (if any).
-
-=head2 right
-
-Returns the right operand (if any).
-
 =head2 DESTROY
 
 Destroys the term and undefines the weak reference to the owner as well
@@ -93,13 +68,10 @@ sub new
     return $self;
 }
 
-sub op    { return $_[0]->{OP}; }
-sub left  { return $_[0]->{LEFT}; }
-sub right { return $_[0]->{RIGHT}; }
-
 sub operate($)
 {
-    Carp::confess( sprintf( q{pure virtual function 'operate' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
+    Carp::confess(
+          sprintf( q{pure virtual function 'operate' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
 }
 
 sub DESTROY
@@ -196,13 +168,7 @@ left and right operand.
 
 =cut
 
-sub operate($)
-{
-    my $left  = $_[0]->{LEFT}->value( $_[1] );
-    my $right = $_[0]->{RIGHT}->value( $_[1] );
-
-    return $left && $right;
-}
+sub operate($) { return $_[0]->{LEFT}->value( $_[1] ) && $_[0]->{RIGHT}->value( $_[1] ); }
 
 package SQL::Statement::Operation::Or;
 
@@ -243,13 +209,7 @@ left and right operand.
 
 =cut
 
-sub operate($)
-{
-    my $left  = $_[0]->{LEFT}->value( $_[1] );
-    my $right = $_[0]->{RIGHT}->value( $_[1] );
-
-    return $left || $right;
-}
+sub operate($) { return $_[0]->{LEFT}->value( $_[1] ) || $_[0]->{RIGHT}->value( $_[1] ); }
 
 package SQL::Statement::Operation::Is;
 
@@ -273,7 +233,7 @@ SQL::Statement::Operation::Is - is operation
 =head1 DESCRIPTION
 
 SQL::Statement::Operation::Is supports: C<IS NULL>, C<IS TRUE> and C<IS FALSE>.
-The right operand is always evaluated in boolean context in case of C<IS TRUE>
+The right operand is always evaluated in boolean contect in case of C<IS TRUE>
 and C<IS FALSE>. C<IS NULL> returns I<true> even if the left term is an empty
 string (C<''>).
 
@@ -311,66 +271,6 @@ sub operate($)
     return $expr;
 }
 
-package SQL::Statement::Operation::ANSI::Is;
-
-use vars qw(@ISA);
-@ISA = qw(SQL::Statement::Operation);
-
-=pod
-
-=head1 NAME
-
-SQL::Statement::Operation::ANSI::Is - is operation
-
-=head1 SYNOPSIS
-
-  # create an C<is> operation with an SQL::Statement object as owner,
-  # specifying the operation name, the left and the right operand
-  my $term = SQL::Statement::Is->new( $owner, $op, $left, $right );
-  # access the result of that operation
-  $term->value( $eval );
-
-=head1 DESCRIPTION
-
-SQL::Statement::Operation::ANSI::Is supports: C<IS NULL>, C<IS TRUE> and C<IS FALSE>.
-The right operand is always evaluated in boolean context in case of C<IS TRUE>
-and C<IS FALSE>. C<IS NULL> returns I<true> if the right term is not defined,
-I<false> otherwise.
-
-=head1 INHERITANCE
-
-  SQL::Statement::Operation::Is
-  ISA SQL::Statement::Operation
-    ISA SQL::Statement::Term
-
-=head1 METHODS
-
-=head2 operate
-
-Returns true when the left term is null, true or false - based on the
-requested right value.
-
-=cut
-
-sub operate($)
-{
-    my $self  = $_[0];
-    my $left  = $self->{LEFT}->value( $_[1] );
-    my $right = $self->{RIGHT}->value( $_[1] );
-    my $expr;
-
-    if ( defined($right) )
-    {
-        $expr = defined($left) ? $left && $right : 0;    # is true / is false
-    }
-    else
-    {
-        $expr = !defined($left);
-    }
-
-    return $expr;
-}
-
 package SQL::Statement::Operation::Contains;
 
 use vars qw(@ISA);
@@ -422,8 +322,7 @@ sub operate($)
 
     foreach my $r (@right)
     {
-        last
-          if $expr |= ( looks_like_number($left) && looks_like_number($r) ) ? $left == $r : $left eq $r;
+        last if $expr |= ( looks_like_number($left) && looks_like_number($r) ) ? $left == $r : $left eq $r;
     }
 
     return $expr;
@@ -479,9 +378,7 @@ sub operate($)
     my @right = map { $_->value($eval); } @{ $self->{RIGHT} };
     my $expr  = 0;
 
-    if (   looks_like_number($left)
-        && looks_like_number( $right[0] )
-        && looks_like_number( $right[1] ) )
+    if ( looks_like_number($left) && looks_like_number( $right[0] ) && looks_like_number( $right[1] ) )
     {
         $expr = ( $left >= $right[0] ) && ( $left <= $right[1] );
     }
@@ -498,7 +395,7 @@ package SQL::Statement::Operation::Equality;
 use vars qw(@ISA);
 @ISA = qw(SQL::Statement::Operation);
 
-use Carp ();
+require Carp;
 use Scalar::Util qw(looks_like_number);
 
 =pod
@@ -519,7 +416,7 @@ SQL::Statement::Operation::Equality - abstract base class for comparisons
 
 SQL::Statement::Operation::Equality implements compare operations between
 two terms - choosing either numerical comparison or string comparison,
-depending whether both operands are numeric or not.
+depending wherther both operands are a numeric or not.
 
 =head1 INHERITANCE
 
@@ -558,12 +455,14 @@ sub operate($)
 
 sub numcmp($)
 {
-    Carp::confess( sprintf( q{pure virtual function 'numcmp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
+    Carp::confess(
+           sprintf( q{pure virtual function 'numcmp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
 }
 
 sub strcmp($)
 {
-    Carp::confess( sprintf( q{pure virtual function 'strcmp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
+    Carp::confess(
+           sprintf( q{pure virtual function 'strcmp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
 }
 
 package SQL::Statement::Operation::Equal;
@@ -907,7 +806,8 @@ sub right($)
 
 sub regexp($)
 {
-    Carp::confess( sprintf( q{pure virtual function 'regexp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
+    Carp::confess(
+           sprintf( q{pure virtual function 'regexp' called on %s for %s}, ref( $_[0] ) || __PACKAGE__, $_[0]->{OP} ) );
 }
 
 sub operate($)
@@ -941,7 +841,7 @@ SQL::Statement::Operation::Like - implements the like operation
 
 =head1 DESCRIPTION
 
-SQL::Statement::Operation::Like is used to the comparisons for the C<LIKE>
+SQL::Statement::Operation::Like is used to to the comparisons for the C<LIKE>
 operation.
 
 =head1 INHERITANCE
@@ -986,7 +886,7 @@ SQL::Statement::Operation::Clike - implements the clike operation
 
 =head1 DESCRIPTION
 
-SQL::Statement::Operation::Clike is used to the comparisons for the C<CLIKE>
+SQL::Statement::Operation::Clike is used to to the comparisons for the C<CLIKE>
 operation.
 
 =head1 INHERITANCE
@@ -1031,7 +931,7 @@ SQL::Statement::Operation::RLike - implements the rlike operation
 
 =head1 DESCRIPTION
 
-SQL::Statement::Operation::RLike is used to the comparisons for the C<RLIKE>
+SQL::Statement::Operation::RLike is used to to the comparisons for the C<RLIKE>
 operation.
 
 =head1 INHERITANCE
@@ -1057,7 +957,7 @@ sub regexp($)
 
 =head1 AUTHOR AND COPYRIGHT
 
-Copyright (c) 2009-2020 by Jens Rehsack: rehsackATcpan.org
+Copyright (c) 2009 by Jens Rehsack: rehsackATcpan.org
 
 All rights reserved.
 
