@@ -1,24 +1,11 @@
 package SQL::Statement::Placeholder;
 
-######################################################################
-#
-# This module is copyright (c), 2009-2020 by Jens Rehsack.
-# All rights reserved.
-#
-# It may be freely distributed under the same terms as Perl itself.
-# See below for help and copyright information (search for SYNOPSIS).
-#
-######################################################################
-
-use strict;
-use warnings FATAL => "all";
-
 use vars qw(@ISA);
-use Carp ();
+require Carp;
 
-use SQL::Statement::Term ();
+require SQL::Statement::Term;
 
-our $VERSION = '1.413_001';
+our $VERSION = '1.21';
 
 @ISA = qw(SQL::Statement::Term);
 
@@ -85,7 +72,7 @@ sub value($)
 
 =head1 AUTHOR AND COPYRIGHT
 
-Copyright (c) 2009-2020 by Jens Rehsack: rehsackATcpan.org
+Copyright (c) 2009 by Jens Rehsack: rehsackATcpan.org
 
 All rights reserved.
 
