@@ -1,22 +1,8 @@
 package SQL::Statement::Term;
 
-######################################################################
-#
-# This module is copyright (c), 2009-2020 by Jens Rehsack.
-# All rights reserved.
-#
-# It may be freely distributed under the same terms as Perl itself.
-# See below for help and copyright information (search for SYNOPSIS).
-#
-######################################################################
-
-use strict;
-use warnings FATAL => "all";
-
-our $VERSION = '1.413_001';
+our $VERSION = '1.21';
 
 use Scalar::Util qw(weaken);
-use Carp ();
 
 =pod
 
@@ -59,10 +45,11 @@ Destroys the term and undefines the weak reference to the owner.
 
 sub new
 {
-    my $class = $_[0];
-    my $owner = $_[1];
+    my ( $class, $owner ) = @_;
 
-    my $self = bless( { OWNER => $owner }, $class );
+    my %instance = ( OWNER => $owner );
+
+    my $self = bless( \%instance, $class );
     weaken( $self->{OWNER} );
 
     return $self;
@@ -74,10 +61,7 @@ sub DESTROY
     undef $self->{OWNER};
 }
 
-sub value($)
-{
-    Carp::confess( sprintf( q{pure virtual function '%s->value' called}, ref( $_[0] ) || __PACKAGE__ ) );
-}
+sub value($) { Carp::confess( sprintf( q{pure virtual function '%s->value' called}, ref( $_[0] ) || __PACKAGE__ ) ); }
 
 package SQL::Statement::ConstantTerm;
 
@@ -137,9 +121,7 @@ package SQL::Statement::ColumnValue;
 use vars qw(@ISA);
 @ISA = qw(SQL::Statement::Term);
 
-use Carp qw(croak);
-use Params::Util qw(_INSTANCE _ARRAY0 _SCALAR);
-use Scalar::Util qw(looks_like_number);
+use Params::Util qw(_INSTANCE);
 
 =pod
 
@@ -190,53 +172,37 @@ sub new
 
 sub value($)
 {
-    my ( $self, $eval ) = @_;
+    my $self = $_[0];
+    my $eval = $_[1];
     unless ( defined( $self->{TMPVAL} ) )
     {
         my ( $tbl, $col ) = $self->{OWNER}->full_qualified_column_name( $self->{VALUE} );
-        defined($tbl) or croak("Can't find table containing column named '$self->{VALUE}'");
-        defined($col) or croak("Unknown column: '$self->{VALUE}'");
         $self->{TMPVAL}      = $tbl . $self->{OWNER}->{dlm} . $col;
         $self->{TABLE_NAME}  = $tbl;
         $self->{COLUMN_NAME} = $col;
     }
 
-    # XXX - can TMPVAL being defined without TABLE_NAME?
-    unless ( defined( $self->{TABLE_NAME} ) )
-    {
-        croak( "No table specified: '" . $self->{OWNER}->{original_string} . "'" );
-    }
-
     # with TempEval: return $eval->column($self->{TABLE_NAME}, $self->{COLUMN_NAME});
-    my $fp;
-    defined( $fp = $self->{fastpath}->{ "${eval}." . $self->{TABLE_NAME} } )
-      and return &$fp( $self->{COLUMN_NAME} );
 
-    defined( $fp = $self->{fastpath}->{ "${eval}." . $self->{TMPVAL} } )
-      and return &$fp( $self->{TMPVAL} );
+    if ( _INSTANCE( $eval, 'SQL::Eval' ) )
+    {
+        my $table = $eval->{tables}->{ $self->{TABLE_NAME} };
+        return $table->column( $self->{COLUMN_NAME} );
 
-    if ( defined( _INSTANCE( $eval, 'SQL::Eval' ) ) )
-    {
-        $self->{fastpath}->{ "${eval}." . $self->{TABLE_NAME} } =
-          $eval->_gen_access_fastpath( $self->{TABLE_NAME} );
-        return &{ $self->{fastpath}->{ "${eval}." . $self->{TABLE_NAME} } }( $self->{COLUMN_NAME} );
-    }
-    elsif ( defined( _INSTANCE( $eval, 'SQL::Eval::Table' ) ) )
-    {
-        $self->{fastpath}->{ "${eval}." . $self->{TMPVAL} } =
-          $eval->_gen_access_fastpath( $self->{TMPVAL} );
-        return &{ $self->{fastpath}->{ "${eval}." . $self->{TMPVAL} } }( $self->{TMPVAL} );
-        # return $eval->column( $self->{TMPVAL} );
+        # return $line->[ $table->{col_nums}->{ $self->{COLUMN_NAME} } ];
     }
     else
     {
-        croak( "Unsupported table storage: '" . ref($eval) . "'" );
+        return undef unless ( defined( $eval->{rowpos} ) );
+        my $line = $eval->{table}->[ $eval->{rowpos} - 1 ];
+
+        return $line->[ $eval->{col_nums}->{ $self->{TMPVAL} } ];
     }
 }
 
 =head1 AUTHOR AND COPYRIGHT
 
-Copyright (c) 2009-2020 by Jens Rehsack: rehsackATcpan.org
+Copyright (c) 2009 by Jens Rehsack: rehsackATcpan.org
 
 All rights reserved.
 
