@@ -1,77 +1,44 @@
 package SQL::Statement::TermFactory;
 
-######################################################################
-#
-# This module is copyright (c), 2009-2020 by Jens Rehsack.
-# All rights reserved.
-#
-# It may be freely distributed under the same terms as Perl itself.
-# See below for help and copyright information (search for SYNOPSIS).
-#
-######################################################################
-
-use strict;
-use warnings FATAL => "all";
-
-use SQL::Statement::Term        ();
-use SQL::Statement::Operation   ();
-use SQL::Statement::Placeholder ();
-use SQL::Statement::Function    ();
+require SQL::Statement::Term;
+require SQL::Statement::Operation;
+require SQL::Statement::Placeholder;
+require SQL::Statement::Function;
 
 use Data::Dumper;
-use Params::Util qw(_HASH _ARRAY0 _INSTANCE);
+use Params::Util qw(_HASH _ARRAY0);
 use Scalar::Util qw(blessed weaken);
 
-our $VERSION = '1.413_001';
+our $VERSION = '1.21';
 
 my %oplist = (
-    '='       => 'Equal',
-    '<>'      => 'NotEqual',
-    'AND'     => 'And',
-    'OR'      => 'Or',
-    '<='      => 'LowerEqual',
-    '>='      => 'GreaterEqual',
-    '<'       => 'Lower',
-    '>'       => 'Greater',
-    'LIKE'    => 'Like',
-    'RLIKE'   => 'Rlike',
-    'CLIKE'   => 'Clike',
-    'IN'      => 'Contains',
-    'BETWEEN' => 'Between',
-    'IS'      => 'Is',
-);
+               '='       => 'Equal',
+               '<>'      => 'NotEqual',
+               'AND'     => 'And',
+               'OR'      => 'Or',
+               '<='      => 'LowerEqual',
+               '>='      => 'GreaterEqual',
+               '<'       => 'Lower',
+               '>'       => 'Greater',
+               'LIKE'    => 'Like',
+               'RLIKE'   => 'Rlike',
+               'CLIKE'   => 'Clike',
+               'IN'      => 'Contains',
+               'BETWEEN' => 'Between',
+               'IS'      => 'Is',
+             );
 
 sub new
 {
-    my ( $class, $owner ) = @_;
-    my $self = bless(
-        {
-            OWNER => $owner,
-        },
-        $class
-    );
+    my $class = shift;
+    my $owner = shift;
+    my $self  = bless( { OWNER => $owner, }, $class );
 
     weaken( $self->{OWNER} );
 
     return $self;
 }
 
-my %opClasses;
-
-sub _getOpClass($)
-{
-    my ( $self, $op ) = @_;
-    unless ( defined( $opClasses{$op} ) )
-    {
-        my $opBase = 'SQL::Statement::Operation';
-        my $opDialect = join( '::', $opBase, $self->{OWNER}->{dialect}, $oplist{$op} );
-        $opClasses{$op} =
-          $opDialect->isa($opBase) ? $opDialect : join( '::', $opBase, $oplist{$op} );
-    }
-
-    return $opClasses{$op};
-}
-
 sub buildCondition
 {
     my ( $self, $pred ) = @_;
@@ -90,7 +57,7 @@ sub buildCondition
         }
         elsif ( defined( $oplist{$op} ) )
         {
-            my $cn    = $self->_getOpClass($op);
+            my $cn    = 'SQL::Statement::Operation::' . $oplist{$op};
             my $left  = $self->buildCondition( $pred->{arg1} );
             my $right = $self->buildCondition( $pred->{arg2} );
             $term = $cn->new( $self->{OWNER}, $op, $left, $right );
@@ -100,11 +67,9 @@ sub buildCondition
             my $left  = $self->buildCondition( $pred->{arg1} );
             my $right = $self->buildCondition( $pred->{arg2} );
 
-            $term = SQL::Statement::Function::UserFunc->new(
-                $self->{OWNER}, $op,
-                $self->{OWNER}->{opts}->{function_names}->{$op},
-                [ $left, $right ]
-            );
+            $term = SQL::Statement::Function::UserFunc->new( $self->{OWNER}, $op,
+                                                             $self->{OWNER}->{opts}->{function_names}->{$op},
+                                                             [ $left, $right ] );
         }
         else
         {
@@ -119,7 +84,7 @@ sub buildCondition
     elsif ( defined( $pred->{type} ) )
     {
         my $type = uc( $pred->{type} );
-        if ( $type =~ m/^(?:STRING|NUMBER|BOOLEAN)$/ )
+        if ( ( $type eq 'STRING' ) || ( $type eq 'NUMBER' ) )
         {
             $term = SQL::Statement::ConstantTerm->new( $self->{OWNER}, $pred->{value} );
         }
@@ -149,18 +114,19 @@ sub buildCondition
             }
             elsif ( $pred->{name} eq 'TRIM' )
             {
-                $term = SQL::Statement::Function::Trim->new( $self->{OWNER}, $pred->{trim_spec}, $pred->{trim_char}, \@params );
+                $term = SQL::Statement::Function::Trim->new( $self->{OWNER}, $pred->{trim_spec}, $pred->{trim_char},
+                                                             \@params );
             }
             elsif ( $pred->{name} eq 'SUBSTRING' )
             {
-                my $start  = $self->buildCondition( $pred->{start} );
-                my $length = $self->buildCondition( $pred->{length} )
-                  if ( _HASH( $pred->{length} ) );
+                my $start = $self->buildCondition( $pred->{start} );
+                my $length = $self->buildCondition( $pred->{length} ) if ( _HASH( $pred->{length} ) );
                 $term = SQL::Statement::Function::SubString->new( $self->{OWNER}, $start, $length, \@params );
             }
             else
             {
-                $term = SQL::Statement::Function::UserFunc->new( $self->{OWNER}, $pred->{name}, $pred->{subname}, \@params );
+                $term =
+                  SQL::Statement::Function::UserFunc->new( $self->{OWNER}, $pred->{name}, $pred->{subname}, \@params );
             }
         }
         else
@@ -168,10 +134,6 @@ sub buildCondition
             return $self->{OWNER}->do_err( sprintf( q{Unknown type '%s'}, $pred->{type} ) );
         }
     }
-    elsif ( defined( _INSTANCE( $pred, 'SQL::Statement::Term' ) ) )
-    {
-        return $pred;
-    }
     else
     {
         return $self->{OWNER}->do_err( sprintf( q~Unknown predicate '{%s}'~, Dumper($pred) ) );
@@ -205,20 +167,15 @@ Those terms are used to access data from the table(s) - either when evaluating
 the where clause or returning column data.
 
 The concept of a factory can be studied in I<Design Patterns> by the Gang of
-Four. The concept of using polymorphism instead of conditions is suggested by
+Four. The concept of using polymophism instead of conditions is suggested by
 Martin Fowler in his book I<Refactoring>.
 
-=head1 METHODS
-
-=head2 buildCondition
-
-Builds a condition object from a given (part of a) where clause. This method
-calls itself recursively for I<predicates>.
-
 =head1 AUTHOR AND COPYRIGHT
 
 Copyright (c) 2001,2005 by Jeff Zucker: jzuckerATcpan.org
-Copyright (c) 2009-2020 by Jens Rehsack: rehsackATcpan.org
+Copyright (c) 2008,2009 by Jens Rehsack: rehsackATcpan.org
+
+Portions Copyright (C) 1998 by Jochen Wiedmann: jwiedATcpan.org
 
 All rights reserved.
 
